import numpy as np


def STD_TXT(input_txt_dir, del_col_list):
    data = np.loadtxt(input_txt_dir)
    data = np.delete(data, del_col_list, axis=1)
    output_txt_dir = input_txt_dir.replace(input_txt_dir.split('\\')[-1], "new_" + input_txt_dir.split('/')[-1])
    np.savetxt(output_txt_dir, data, fmt='%.4f')




import setuptools


setuptools.setup(
    name="NJFU",
    version="0.0.6",
    author="XHF",

    description="NJFU",

    Long_description_content_type="Tool for NJFU",
    url="https://github.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Utilities",
    ],
)
